@@ -120,18 +120,23 @@ readRCV1asPlain <- readXML(spec = list(Author = list("unevaluated", ""),
 readDOC <- FunctionGenerator(function(AntiwordOptions = "", ...) {
     AntiwordOptions <- AntiwordOptions
     function(elem, language, id) {
-        content <- system(paste("antiword", AntiwordOptions, shQuote(elem$uri)), intern = TRUE)
+        content <- system2("antiword",
+                           c(AntiwordOptions, shQuote(elem$uri)),
+                           stdout = TRUE)
         PlainTextDocument(content, id = id, language = language)
     }
 })
 
-# readPDF needs pdftotext installed to be able to extract the text
+# readPDF needs pdfinfo and pdftotext installed to extract meta data and text
 readPDF <- FunctionGenerator(function(PdftotextOptions = "", ...) {
     PdftotextOptions <- PdftotextOptions
     function(elem, language, id) {
-        meta <- tools:::pdf_info(elem$uri)
-        content <- system(paste("pdftotext", PdftotextOptions, shQuote(elem$uri), "-"), intern = TRUE)
-        PlainTextDocument(content, meta$Author, meta$CreationDate, meta$Subject, meta$Title, id, meta$Creator, language)
+        meta <- tm:::pdfinfo(elem$uri)
+        content <- system2("pdftotext",
+                           c(PdftotextOptions, shQuote(elem$uri), "-"),
+                           stdout = TRUE)
+        PlainTextDocument(content, meta$Author, meta$CreationDate, meta$Subject,
+                          meta$Title, id, meta$Creator, language)
      }
 })
 
